from django.apps import AppConfig


class WagtailInventoryAppConfig(AppConfig):
    name = "wagtailinventory"
    verbose_name = "Wagtail Inventory"
    default_auto_field = "django.db.models.BigAutoField"
